==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Layerwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Layerwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Layer</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation>Alle Layer anzeigen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Alle Layer verbergen</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation>Alle Layer sperren</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Alle Layer entsperren</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+29"/>
        <source>Layer name:</source>
        <translation>Layername:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Stift</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Linienbreite:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Linientyp:</translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Layer Data</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Layername ist leer.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Layer besteht schon.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>Layerwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Layerwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Layer</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>Alle Layer anzeigen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Alle Layer verbergen</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>Alle Layer auftauen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>Alle Layer einfrieren</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>Alle Layer sperren</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Alle Layer entsperren</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+29"/>
        <source>Layer name:</source>
        <translation>Layername:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Stift</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Linienbreite:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Linientyp:</translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Layer Data</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>Führende oder nachfolgende Leerzeichen.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translation>Layername ist leer.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translation>Layer besteht schon.</translation>
    </message>
</context>
</TS>
